struct ImageResource {
data: CachedImageData,
descriptor: ImageDescriptor,
tiling: Option<TileSize>,
visible_rect: DeviceIntRect,
adjustment: AdjustedImageSource,
generation: ImageGeneration,
}Fields
data: CachedImageDatadescriptor: ImageDescriptortiling: Option<TileSize>visible_rect: DeviceIntRectThis is used to express images that are virtually very large but with only a visible sub-set that is valid at a given time.
adjustment: AdjustedImageSourcegeneration: ImageGenerationAuto Trait Implementations
impl Freeze for ImageResource
impl RefUnwindSafe for ImageResource
impl Send for ImageResource
impl Sync for ImageResource
impl Unpin for ImageResource
impl UnsafeUnpin for ImageResource
impl UnwindSafe for ImageResource